import json
import os
from dataclasses import dataclass


_DAEMON_CONFIG_PATH = "/etc/clwpos/daemon_conf.json"

@dataclass
class Config:
    monitoring_interval: int = 300
    enable_reload_rate_limit: bool = True

    logging_level: str = 'INFO'


def load_config(config_file: str = _DAEMON_CONFIG_PATH) -> Config:
    if not os.path.exists(config_file):
        return Config()

    with open(config_file) as f:
        raw_config = json.load(f)

    # config is mostly used in tests and dev machines,
    # so we don't care much about broken configs or wrong params
    config = Config(**raw_config)

    return config